<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AttributeWindow</name>
    <message>
        <location filename="../src/attributewindow.cpp" line="23"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
</context>
<context>
    <name>CacheProvider</name>
    <message>
        <location filename="../src/cacheprovider.cpp" line="381"/>
        <source>&amp;Cache Provider</source>
        <translation>&amp;Cache-Datenquelle</translation>
    </message>
</context>
<context>
    <name>CacheWindow</name>
    <message>
        <source>Placed by</source>
        <translation type="obsolete">Gelegt von</translation>
    </message>
    <message>
        <source>Difficulty</source>
        <translation type="obsolete">Schwierigkeit</translation>
    </message>
    <message>
        <source>Terrain</source>
        <translation type="obsolete">Gelände</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="obsolete">Behälter</translation>
    </message>
    <message>
        <location filename="../src/cachewindow.cpp" line="170"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/cachewindow.cpp" line="180"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../src/cachewindow.cpp" line="190"/>
        <source>Hint</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <location filename="../src/cachewindow.cpp" line="200"/>
        <source>Logs</source>
        <translation>Logs</translation>
    </message>
    <message>
        <location filename="../src/cachewindow.cpp" line="210"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <source>Open in browser</source>
        <translation type="obsolete">Im Browser öffnen</translation>
    </message>
</context>
<context>
    <name>CoordinateTool</name>
    <message>
        <location filename="../src/coordinatetool.cpp" line="125"/>
        <source>New waypoint</source>
        <translation>Neuer Wegpunkt</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="136"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="145"/>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="170"/>
        <source>New Coordinate</source>
        <translation>Neue Koordinate</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="171"/>
        <source>Edit Coordinate</source>
        <translation>Koordinate bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="334"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="335"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="351"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="352"/>
        <source>E</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="439"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="442"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="446"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="450"/>
        <source>Copy to clipboard</source>
        <translation>Kopiere in Zwischenablage</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="487"/>
        <source>Latitude</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../src/coordinatetool.cpp" line="492"/>
        <source>Longitude</source>
        <translation>Länge</translation>
    </message>
</context>
<context>
    <name>CustomWindow</name>
    <message>
        <location filename="../src/customwindow.cpp" line="67"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
</context>
<context>
    <name>DescriptionWindow</name>
    <message>
        <location filename="../src/descriptionwindow.cpp" line="22"/>
        <source>Open in browser</source>
        <translation>Im Browser öffnen</translation>
    </message>
</context>
<context>
    <name>GcBrowser</name>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="103"/>
        <source>No valid login specified, cache positions will be inaccurate!</source>
        <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="235"/>
        <source>!Network connection failed, please make sure you are connected to the internet and restart CacheMe!</source>
        <translation>!Netzwerkverbindung fehlgeschlagen. Bitte stellen Sie sicher, dass Sie mit dem Netzwerk verbunden sind und starten Sie CacheMe neu!</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="275"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="325"/>
        <source>Login failed!</source>
        <translation>Einloggen fehlgeschlagen!</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="478"/>
        <source>Unable to determine cache id!</source>
        <translation>Cache-ID nicht feststellbar!</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="506"/>
        <source>Unable to determine cache guid!</source>
        <translation>Cache-Guid nicht feststellbar!</translation>
    </message>
    <message>
        <source>Plugin:</source>
        <translation type="obsolete">Erweiterung:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Passwort</translation>
    </message>
</context>
<context>
    <name>GcDialog</name>
    <message>
        <source>GcLive login</source>
        <translation type="obsolete">GcLive-Login</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Passwort</translation>
    </message>
</context>
<context>
    <name>GcLive</name>
    <message>
        <source>No valid login specified, cache positions will be inaccurate!</source>
        <translation type="obsolete">Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
    </message>
    <message>
        <source>Login successful!</source>
        <translation type="obsolete">Einloggen erfolgreich!</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>Login failed!</source>
        <translation type="obsolete">Einloggen fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Unable to determine cache id!</source>
        <translation type="obsolete">Cache-ID nicht feststellbar!</translation>
    </message>
    <message>
        <source>Unable to determine cache guid!</source>
        <translation type="obsolete">Cache-Guid nicht feststellbar!</translation>
    </message>
    <message>
        <source>Plugin:</source>
        <translation type="obsolete">Erweiterung:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Passwort</translation>
    </message>
</context>
<context>
    <name>GcParser</name>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="310"/>
        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="318"/>
        <source>Too many caches</source>
        <translation>Zu viele Caches</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="311"/>
        <source>No caches in this area</source>
        <translation>Keine Caches in dieser Gegend</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="381"/>
        <source>Error downloading caches</source>
        <translation>Fehler beim Laden der Caches</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="451"/>
        <source>Error downloading cache info</source>
        <translation>Fehler beim Download der Cache-Info</translation>
    </message>
</context>
<context>
    <name>Gpx</name>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="73"/>
        <source>File %1 does not contain any geocaches</source>
        <translation>Die Datei %1 enthält keine Geocaches</translation>
    </message>
    <message>
        <source>Open Pocket Query (GPX or ZIP)</source>
        <translation type="obsolete">Pocket-Query öffnen (GPX oder ZIP)</translation>
    </message>
    <message>
        <source>Pocket Queries (*.gpx *.zip)</source>
        <translation type="obsolete">Pocket-Queries (*.gox *.zip)</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="102"/>
        <source>Open Pocket Query (GPX, LOC or ZIP)</source>
        <translation>Pocket-Query öffnen (GPX, LOC oder ZIP)</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="103"/>
        <source>Pocket Queries (*.gpx *.loc *.zip)</source>
        <translation>Pocket-Queries (*.gpx *.loc *.zip)</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="112"/>
        <source>File %1 not found</source>
        <translation>Datei %1 nicht gefunden</translation>
    </message>
    <message>
        <source>No caches in this area</source>
        <translation type="obsolete">Keine Caches in dieser Gegend</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="179"/>
        <source>Unable to get cache info</source>
        <translation>Kann Cache-Info nicht laden</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="195"/>
        <source>Unable to get cache detail</source>
        <translation>Kann Cache-Details nicht laden</translation>
    </message>
    <message>
        <source>Plugin:</source>
        <translation type="obsolete">Erweiterung:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="obsolete">Benutzername</translation>
    </message>
</context>
<context>
    <name>HintDialog</name>
    <message>
        <source>Hint</source>
        <translation type="obsolete">Hinweis</translation>
    </message>
</context>
<context>
    <name>HintWindow</name>
    <message>
        <location filename="../src/cachewindow.cpp" line="30"/>
        <source>Hint</source>
        <translation>Hinweis</translation>
    </message>
</context>
<context>
    <name>LogWidget</name>
    <message>
        <location filename="../src/logwindow.cpp" line="27"/>
        <source>by</source>
        <translation>von</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../src/logwindow.cpp" line="45"/>
        <source>Logs</source>
        <translation>Logs</translation>
    </message>
    <message>
        <location filename="../src/logwindow.cpp" line="59"/>
        <source>Create new log</source>
        <translation>Neuen Log-Eintrag erstellen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Datei</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="obsolete">B&amp;eenden</translation>
    </message>
    <message>
        <source>&amp;Map</source>
        <translation type="obsolete">&amp;Karte</translation>
    </message>
    <message>
        <source>Map &amp;Settings</source>
        <translation type="obsolete">&amp;Karteneinstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="27"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="26"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="53"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="70"/>
        <source>About CacheMe</source>
        <translation>Über CacheMe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="71"/>
        <location filename="../src/mainwindow.cpp" line="86"/>
        <source>CacheMe</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="71"/>
        <source>Version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="72"/>
        <source>Build date:</source>
        <translation>Erstellungsdatum:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="73"/>
        <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
        <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
</oldsource>
        <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="74"/>
        <source>CacheMe is an online geocaching application.</source>
        <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>This copy of CacheMe has expired and will close in one minute!</source>
        <translation>Diese Kopie von CacheMe ist abgelaufen und wird in einer Minute geschlossen!</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>This copy of CacheMe will expire in %1 days!</source>
        <translation>Diese Kopie von CacheMe läuft in %1 Tagen aus!</translation>
    </message>
</context>
<context>
    <name>MapDialog</name>
    <message>
        <source>Map settings</source>
        <translation type="obsolete">Karteneinstellungen</translation>
    </message>
    <message>
        <source>Street Map</source>
        <translation type="obsolete">Straßenkarte</translation>
    </message>
    <message>
        <source>Satellite Map Day</source>
        <translation type="obsolete">Satellitenkarte Tag</translation>
    </message>
    <message>
        <source>Satellite Map Night</source>
        <translation type="obsolete">Satellitenkarte Nacht</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation type="obsolete">Geländekarte</translation>
    </message>
    <message>
        <source>Map type</source>
        <translation type="obsolete">Kartentyp</translation>
    </message>
    <message>
        <source>Map service</source>
        <translation type="obsolete">Kartendienst</translation>
    </message>
    <message>
        <source>A change of the map service takes effect after restart.</source>
        <translation type="obsolete">Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
    </message>
</context>
<context>
    <name>MapWidget</name>
    <message>
        <source>Maximum zoom level reached</source>
        <translation type="obsolete">Maximaler Zoom-Level erreicht</translation>
    </message>
    <message>
        <source>Minimum zoom level reached</source>
        <translation type="obsolete">Minimaler Zoom-Level erreicht</translation>
    </message>
    <message>
        <source>Error opening cache url </source>
        <translation type="obsolete">Fehler beim Öffnen der Cache-Url</translation>
    </message>
    <message>
        <source>Opening &quot;%1&quot; in browser ...</source>
        <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
    </message>
    <message>
        <location filename="../src/mapwidget.cpp" line="425"/>
        <source>Displayed cache data is %1 weeks old!</source>
        <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
    </message>
</context>
<context>
    <name>NavigationWindow</name>
    <message>
        <location filename="../src/navigationwindow.cpp" line="111"/>
        <source>Distance</source>
        <translation>Entfernung</translation>
    </message>
    <message>
        <source>Current coordinate:</source>
        <translation type="obsolete">Aktuelle Koordinate:</translation>
    </message>
    <message>
        <location filename="../src/navigationwindow.cpp" line="100"/>
        <source>Latitude</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../src/navigationwindow.cpp" line="102"/>
        <source>Longitude</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Cache coordinate:</source>
        <translation type="obsolete">Cache-Koordinate:</translation>
    </message>
    <message>
        <location filename="../src/navigationwindow.cpp" line="77"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <source>Current coordinate</source>
        <translation type="obsolete">Aktuelle Koordinate</translation>
    </message>
    <message>
        <source>Cache coordinate</source>
        <translation type="obsolete">Cache-Koordinate</translation>
    </message>
    <message>
        <source>S</source>
        <translation type="obsolete">S</translation>
    </message>
    <message>
        <source>N</source>
        <translation type="obsolete">N</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="obsolete">W</translation>
    </message>
    <message>
        <source>E</source>
        <translation type="obsolete">O</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/mapbubble.cpp" line="259"/>
        <source>Difficulty</source>
        <translation>Schwierigkeit</translation>
    </message>
    <message>
        <location filename="../src/mapbubble.cpp" line="260"/>
        <source>Terrain</source>
        <translation>Gelände</translation>
    </message>
    <message>
        <location filename="../src/mapbubble.cpp" line="263"/>
        <source>Placed on</source>
        <translation>Gelegt am</translation>
    </message>
    <message>
        <location filename="../src/mapbubble.cpp" line="265"/>
        <source>by</source>
        <translation>von</translation>
    </message>
    <message>
        <location filename="../src/mapbubble.cpp" line="267"/>
        <source>Placed by</source>
        <translation>Gelegt von</translation>
    </message>
    <message>
        <location filename="../src/mapbubble.cpp" line="272"/>
        <source>Container</source>
        <translation>Behälter</translation>
    </message>
    <message>
        <source>Container size</source>
        <translation type="obsolete">Behältergröße</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="279"/>
        <source>Found it</source>
        <translation>Gefunden</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="280"/>
        <source>Didn&apos;t find it</source>
        <translation>Nicht gefunden</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="281"/>
        <source>Owner Maintenance</source>
        <translation>Wartung durch Besitzer</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="282"/>
        <source>Write Note</source>
        <translation>Notiz geschrieben</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="283"/>
        <source>Post Reviewer Note</source>
        <translation>Gutachter-Notiz</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="284"/>
        <source>Enable Listing</source>
        <translation>Eingestellt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="285"/>
        <source>Publish Listing</source>
        <translation>Veröffentlicht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="286"/>
        <source>Will Attend</source>
        <translation>Werde teilnehmen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="287"/>
        <source>Attended</source>
        <translation>Teilgenommen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="288"/>
        <source>Webcam Photo taken</source>
        <translation>Webcam-Foto gemacht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="289"/>
        <source>Temporarily Disable Listing</source>
        <translation>Zeitweilig deaktiviert</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="140"/>
        <location filename="../src/cache.cpp" line="290"/>
        <source>Needs Maintenance</source>
        <translation>Benötigt Wartung</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="60"/>
        <source>Dogs Allowed</source>
        <translation>Hunde erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="60"/>
        <source>No Dogs Allowed</source>
        <translation>Keine Hunde erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="62"/>
        <source>Access or Parking Fee</source>
        <translation>Zufahrts- oder Parkgebühr</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="62"/>
        <source>No Access or Parking Fee</source>
        <translation>Keine Zufahrts- oder Parkgebühr</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="64"/>
        <source>Climbing Gear Required</source>
        <translation>Kletterausrüstung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="64"/>
        <source>No Climbing Gear Required</source>
        <translation>Keine Kletterausrüstung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="66"/>
        <source>Boat Required</source>
        <translation>Boot erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="66"/>
        <source>No Boat Required</source>
        <translation>Kein Boot erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="68"/>
        <source>Scuba Gear Required</source>
        <translation>Tauchausrüstung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="68"/>
        <source>No Scuba Gear Required</source>
        <translation>Keine Tauchausrüstung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="70"/>
        <source>Recommended for Kids</source>
        <translation>Empfohlen für Kinder</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="70"/>
        <source>Not Recommended for Kids</source>
        <translation>Nicht empfohlen für Kinder</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="72"/>
        <source>Takes Less Than an Hour</source>
        <translation>Benötigt weniger als eine Stunde</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="72"/>
        <source>Takes More Than an Hour</source>
        <translation>Benötigt mehr als eine Stunde</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="74"/>
        <source>Scenic View</source>
        <translation>Besondere Aussicht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="74"/>
        <source>No Scenic View</source>
        <translation>Keine besondere Aussicht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="76"/>
        <source>Hiking Required</source>
        <translation>Wandern erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="76"/>
        <source>No Hiking Required</source>
        <translation>Keine Wandern erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="78"/>
        <source>Difficult Climbing</source>
        <translation>Schwieriges Klettern erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="78"/>
        <source>No Difficult Climbing</source>
        <translation>Kein schwieriges Klettern erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="80"/>
        <source>May Require Wading</source>
        <translation>Kann Waten erfordern</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="80"/>
        <source>Does not Require Wading</source>
        <translation>Kein Waten erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="82"/>
        <source>May Require Swimming</source>
        <translation>Kann Schwimmen erfordern</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="82"/>
        <source>Does not Require Swimming</source>
        <translation>Kein Schwimmen erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="84"/>
        <source>Available at All Times</source>
        <translation>Zu jeder Zeit verfügbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="84"/>
        <source>Not Available at All Times</source>
        <translation>Nicht zu jeder Zeit verfügbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="86"/>
        <source>Recommended at Night</source>
        <translation>Empfohlen bei Nacht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="86"/>
        <source>Not Recommended at Night</source>
        <translation>Nicht empfohlen bei Nacht</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="88"/>
        <source>Available During Winter</source>
        <translation>Im Winter verfügbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="88"/>
        <source>Not Available During Winter</source>
        <translation>Nicht im Winter verfügbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="90"/>
        <source>Poisonous Plants</source>
        <translation>Giftige Pflanzen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="90"/>
        <source>No Poisonous Plants</source>
        <translation>Keine giftigen Pflanzen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="92"/>
        <source>Dangerous Animals</source>
        <translation>Gefährliche Tiere</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="92"/>
        <source>No Dangerous Animals</source>
        <translation>Keine gefährlichen Tiere</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="94"/>
        <source>Ticks</source>
        <translation>Zecken</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="94"/>
        <source>No Ticks</source>
        <translation>Keine Zecken</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="96"/>
        <source>Abandoned Mines</source>
        <translation>Aufgegebene Mienen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="96"/>
        <source>No Abandoned Mines</source>
        <translation>Keine aufgegebenen Mienen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="98"/>
        <source>Cliff / Falling Rocks</source>
        <translation>Kliff/herab fallende Felsen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="98"/>
        <source>No Cliff / Falling Rocks</source>
        <translation>Kein Kliff/herab fallenden Felsen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="100"/>
        <source>Hunting</source>
        <translation>Jagd</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="100"/>
        <source>No Hunting</source>
        <translation>Keine Jagd</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="102"/>
        <source>Dangerous Area</source>
        <translation>Gefährliches Gebiet</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="102"/>
        <source>No Dangerous Area</source>
        <translation>Ungefährliches Gebiet</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="104"/>
        <source>Wheelchair Accessible</source>
        <translation>Mit Rollstuhl erreichbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="104"/>
        <source>Not Wheelchair Accessible</source>
        <translation>Nicht mit Rollstuhl erreichbar</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="106"/>
        <source>Parking Available</source>
        <translation>Parkplätze vorhanden</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="106"/>
        <source>No Parking Available</source>
        <translation>Keine Parkplätze vorhanden</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="108"/>
        <source>Public Transportation Nearby</source>
        <translation>Öffentlicher Nahverkehr in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="108"/>
        <source>No Public Transportation Nearby</source>
        <translation>Kein öffentliche Nahverkehr un der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="110"/>
        <source>Drinking Water Nearby</source>
        <translation>Trinkwasser in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="110"/>
        <source>No Drinking Water Nearby</source>
        <translation>Kein Trinkwasser in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="112"/>
        <source>Public Restrooms Nearby</source>
        <translation>Öffentliche WCs in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="112"/>
        <source>No Public Restrooms Nearby</source>
        <translation>Keine öffentlichen WCs in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="114"/>
        <source>Public Phone Nearby</source>
        <translation>Öffentliches Telefon in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="114"/>
        <source>No Public Phone Nearby</source>
        <translation>Kein öffentliches Telefon in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="116"/>
        <source>Picnic Tables Nearby</source>
        <translation>Picknick-Tische in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="116"/>
        <source>No Picnic Tables Nearby</source>
        <translation>Keine Picknick-Tische in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="118"/>
        <source>Camping Available</source>
        <translation>Camping möglich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="118"/>
        <source>Camping Not Available</source>
        <translation>Kein Camping möglich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="120"/>
        <source>Bicycles Allowed</source>
        <translation>Fahrräder erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="120"/>
        <source>Bicycles Not Allowed</source>
        <translation>Keine Fahrräder erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="122"/>
        <source>Motorcycles Allowed</source>
        <translation>Motorräder erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="122"/>
        <source>Motorcycles Not Allowed</source>
        <translation>Keine Motorräder erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="124"/>
        <source>Quads Allowed</source>
        <translation>Quads erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="124"/>
        <source>Quads Not Allowed</source>
        <translation>Keine Quads erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="126"/>
        <source>Off-Road Vehicles Allowed</source>
        <translation>Geländefahrzeuge erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="126"/>
        <source>Off-Road Vehicles Not Allowed</source>
        <translation>Keine Geländefahrzeuge erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="128"/>
        <source>Snowmobiles Allowed</source>
        <translation>Schneemobile erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="128"/>
        <source>Snowmobiles Not Allowed</source>
        <translation>Keine Schneemobile erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="130"/>
        <source>Horses Allowed</source>
        <translation>Pferde erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="130"/>
        <source>Horses Not Allowed</source>
        <translation>Keine Pferde erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="132"/>
        <source>Campfires Allowed</source>
        <translation>Lagerfeuer erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="132"/>
        <source>Campfires Not Allowed</source>
        <translation>Kein Lagerfeuer erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="134"/>
        <source>Thorns!</source>
        <translation>Dornen!</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="134"/>
        <source>No Thorns</source>
        <translation>Keine Dornen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="136"/>
        <source>Stealth Required</source>
        <translation>Tarnung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="136"/>
        <source>No Stealth Required</source>
        <translation>Keine Tarnung erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="138"/>
        <source>Stroller Accessible</source>
        <translation>Kinderwagentauglich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="138"/>
        <source>Not Stroller Accessible</source>
        <translation>Nicht Kinderwagentauglich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="140"/>
        <source>Does Not Need Maintenance</source>
        <translation>Benötigt keine Warung</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="142"/>
        <source>Watch for Livestock</source>
        <translation>Auf Tiere achten</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="142"/>
        <source>Don&apos;t Watch for Livestock</source>
        <translation>Nicht auf Tiere achten</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="144"/>
        <source>Flashlight Required</source>
        <translation>Taschenlampe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="144"/>
        <source>No Flashlight Required</source>
        <translation>Keine Taschenlampe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="146"/>
        <source>Lost &amp; Found Cache</source>
        <translation>&quot;Lost &amp; Found&quot;-Cache</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="146"/>
        <source>No Lost &amp; Found Cache</source>
        <translation>Kein &quot;Lost &amp; Found&quot;-Cache</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="148"/>
        <source>Truck Driver/RV Allowed</source>
        <translation>Lastenwagen und Campingbusse erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="148"/>
        <source>Truck Driver/RV Not Allowed</source>
        <translation>Keine Lastenwagen und Campingbusse erlaubt</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="150"/>
        <source>Field Puzzle</source>
        <translation>Feld-Rätsel</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="150"/>
        <source>No Field Puzzle</source>
        <translation>Kein Feld-Rätsel</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="152"/>
        <source>UV Light Required</source>
        <translation>UV-Lampe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="152"/>
        <source>No UV Light Required</source>
        <translation>Keine UV-Lampe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="154"/>
        <source>Snowshoes Required</source>
        <translation>Schneeschuhe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="154"/>
        <source>No Snowshoes Required</source>
        <translation>Keine Schneeschuhe erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="156"/>
        <source>Cross Country Skis Required</source>
        <translation>Langlaufskier erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="156"/>
        <source>No Cross Country Skis Required</source>
        <translation>Keine Langlaufskier erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="158"/>
        <source>Special Tool Required</source>
        <translation>Spezialwerkzeug erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="158"/>
        <source>No Special Tool Required</source>
        <translation>Kein Spezialwerkzeug erforderlich</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="160"/>
        <source>No Night Cache</source>
        <translation>Kein Nacht-Cache</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="160"/>
        <source>Night Cache</source>
        <translation>Nacht-Cache</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="162"/>
        <source>Park And Grab</source>
        <translation>Parken-und-Mitnehmen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="162"/>
        <source>No Park And Grab</source>
        <translation>Kein Parken-und-Mitnehmen</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="164"/>
        <source>Abandoned Structure</source>
        <translation>Verlassene Gebäude</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="164"/>
        <source>No Abandoned Structure</source>
        <translation>Keine Verlassenen Gebäude</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="166"/>
        <source>Hike Shorter than 1km</source>
        <translation>Wanderung kürzer als 1km</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="166"/>
        <source>Hike Longer than 1km</source>
        <translation>Wanderung länger als 1km</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="168"/>
        <location filename="../src/cache.cpp" line="170"/>
        <source>Hike Shorter than 10km</source>
        <translation>Wanderung küzer als 10km</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="168"/>
        <location filename="../src/cache.cpp" line="170"/>
        <source>Hike Longer than 10km</source>
        <translation>Wanderung länger als 10km</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="172"/>
        <source>Fuel Nearby</source>
        <translation>Treibstoff in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="172"/>
        <source>No Fuel Nearby</source>
        <translation>Kein Treibstoff in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="174"/>
        <source>Food Nearby</source>
        <translation>Nahrungsmittel in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="174"/>
        <source>No Food Nearby</source>
        <translation>Keine Nahrungsmittel in der Nähe</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="176"/>
        <source>&lt;not unknown&gt;</source>
        <translation>&lt;nicht unbekannt&gt;</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="291"/>
        <source>Update Coordinates</source>
        <translation>Koordinaten aktualisiert</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="292"/>
        <source>Unarchive</source>
        <translation>Dearchiviert</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="293"/>
        <source>Needs Archived</source>
        <translation>Sollte archiviert werden</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="294"/>
        <source>Archive</source>
        <translation>Archiviert</translation>
    </message>
    <message>
        <location filename="../src/cache.cpp" line="176"/>
        <location filename="../src/cache.cpp" line="295"/>
        <source>&lt;unknown&gt;</source>
        <translation>&lt;unbekannt&gt;</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="200"/>
        <source>GPL version 2
Copyright 2011 by Till Harbaum
QSgml parts Copyright 2010 by Andreas Lehmann</source>
        <translation>GPL version 2
Copyright 2011 durch Till Harbaum
QSgml-Teile Copyright 2010 durch Andreas Lehmann</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="46"/>
        <source>GPL version 2
Copyright 2011 by Till Harbaum
Quazip parts Copyright 2005 by Sergey A. Tachenov</source>
        <translation>GPL versoin 2
Copyright 2011 durch Till Harbaum
Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="26"/>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="42"/>
        <source>Parse error at line %1, column %2:
%3</source>
        <translation>Lesefehler in Zeile %1, Spalte %2:
%3</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="69"/>
        <source>Cannot open file %1: Code %2</source>
        <translation>Kann datei %1 nicht öffnen: Code %2</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="86"/>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="145"/>
        <source>Cannot open file %1 for reading:
%2</source>
        <translation>Kann Datei %1 nicht zum Lesen öffnen:
%2</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="124"/>
        <source>Zip error in %1: Code %2</source>
        <translation>Zip-Fehler in %1: Code %2</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="139"/>
        <source>File is a waypoint file</source>
        <translation>Datei ist eine Wegpunkt-Datei</translation>
    </message>
    <message>
        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="171"/>
        <source>Unsupported file type: %1</source>
        <translation>Nicht unterstützter Dateityp: %1</translation>
    </message>
    <message>
        <source>Unsupported file type: %2</source>
        <translation type="obsolete">Nicht unterstützter Dateityp: %2</translation>
    </message>
</context>
<context>
    <name>QuaZipFile</name>
    <message>
        <location filename="../plugins/cacheprovider/gpx/quazip-0.3/quazip/quazipfile.cpp" line="141"/>
        <source>ZIP/UNZIP API error %1</source>
        <translation>ZIP/UNZIP API-Fehler %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="88"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="82"/>
        <source>Hybrid Map</source>
        <translation>Hybridkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="82"/>
        <source>Transit Map</source>
        <translation>ÖPNV-Karte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>Gray Street Map</source>
        <translation>Graue Straßenkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>Mobile Street Map</source>
        <translation>Mobile Straßenkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="84"/>
        <source>Mobile Terrain Map</source>
        <translation>Mobile Geländekarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="84"/>
        <source>Mobile Hybrid Map</source>
        <translation>Mobile Hybridkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="85"/>
        <source>Mobile Transit Map</source>
        <translation>Mobile ÖPNV-Karte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="85"/>
        <source>Mobile Gray Street Map</source>
        <translation>Mobile graue Straßenkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="107"/>
        <source>Service</source>
        <translation>Dienst</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="126"/>
        <source>Bigger icons</source>
        <translation>Große Icons</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="131"/>
        <source>Hide owned/found</source>
        <translation>Eigene/gefundene verstecken</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="182"/>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="183"/>
        <source>Account</source>
        <translation>Zugang</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="80"/>
        <source>Street Map</source>
        <translation>Straßenkarte</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="80"/>
        <source>Satellite Map Day</source>
        <translation>Satellitenkarte Tag</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="81"/>
        <source>Satellite Map Night</source>
        <translation>Satellitenkarte Nacht</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="81"/>
        <source>Terrain Map</source>
        <translation>Geländekarte</translation>
    </message>
    <message>
        <source>Map type</source>
        <translation type="obsolete">Kartentyp</translation>
    </message>
    <message>
        <source>Map service</source>
        <translation type="obsolete">Kartendienst</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="120"/>
        <source>A change of the map service takes effect after restart.</source>
        <translation>Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
    </message>
    <message>
        <source>High density display</source>
        <translation type="obsolete">Hoch auflösender Bildschirm</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="149"/>
        <source>Geocaching.com account</source>
        <translation>Geocaching.com-Zugang</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="154"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="159"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
</TS>
